@@ -9,6 +9,14 @@ SPACE_REGEX = re.compile(r'\s+')
 
 
 def map_owoify_levels(word: Word, level: str) -> Word:
+    """
+    Utility function to map different level of owoness to the string.
+    For internal use only.
+    :exception RuntimeError: When the inputted owoness level is incorrect.
+    :param word: The source Word to owoify.
+    :param level: The desired owoness level.
+    :return: The owoified Word.
+    """
     level = level.lower()
     for func in SPECIFIC_WORD_MAPPING_LIST:
         word = func(word)
@@ -33,6 +41,13 @@ def map_owoify_levels(word: Word, level: str) -> Word:
 
 
 def owoify(source: str, level: str = 'owo') -> str:
+    """
+    The main entry point of owoify. Pass the source string and the desired level of owoness to owoify it.
+    :exception RuntimeError: When the inputted owoness level is incorrect.
+    :param source: The source string to owoify.
+    :param level: The owoness to apply to the string. Available options are: `owo`, `uwu`, `uvu` (from low to high).
+    :return: The owoified string.
+    """
     word_matches = WORD_REGEX.findall(source)
     space_matches = SPACE_REGEX.findall(source)
 
